##############################################################################################
# bring in data from an outside tab delimited text file, can be converted from a EXCEL file
#     (shown in this example)
#
##############################################################################################


rm(list=ls(all=TRUE))  # remove anything that might be remaining from prior analyses


# change this to read in the correct data file with the full path ############################
treedat<- read.table("E:\\R_workshop\\workshop 2009\\data\\african_trees.txt",header=TRUE)

attach(treedat)
names(treedat)

Dbhsq<-Dbh^2  # Dbh squared
logDbh<-log(Dbh) #log Dbh
loght<- log(Ht)  # log height

treedat2<- data.frame(treedat,Dbhsq,logDbh,loght)

detach(treedat)
rm(treedat,logDbh,loght,Dbhsq)

attach(treedat2)
names(treedat2)
ls()
treedat2[1:5,]

lm.height<-lm(Ht~Dbh+Dbhsq)  # parabola shape
lm.height
summary(lm(Ht~Dbh+Dbhsq))
anova(lm(Ht~Dbh+Dbhsq))

yhat<-fitted(lm.height)
resid<-resid(lm.height)
cbind(Ht,yhat,resid)  # list measured and predicted height and differences (i.e. residuals)

plot(yhat~Ht)
abline(a=0,b=1)   # plot a reference line where yhat equals height 

plot(resid~yhat)  # residual plot

plot(resid~Dbh)    #different residual plot

qqnorm(resid)     # normality plot
qqline(resid,col=2)

hist(resid, breaks =6 , density=10,col="green", border="black") # draws a histogram

# get 95% confidence intervals for the average height, given each of the Dbh's in the data, using the equation
predCI<- predict(lm.height, treedat2,interval="confidence")
predCI

# plot the orginal data, the predicted values and 95% confidence interval bands
rank<- order(Dbh)
sortedpredCI=predCI[rank,]
Dbhsort<-Dbh[rank]
plot(Dbh,Ht)
matlines(Dbhsort,sortedpredCI,lty=c(1,2,2),color="black") #overlay the predicted values and CI using linetypes given

# get confidence intervals for the average heights for Dbh=20 cm
Dbhnew<-20.0
Dbhsqnew<-Dbhnew^2
new <- data.frame(Dbh=Dbhnew,Dbhsq=Dbhsqnew) 

# default is for a 95 percent confidence interval for mean y given the x.  Can change the percent by including the level
pred.w.clim <- predict(lm(Ht~ Dbh+Dbhsq), new, interval="confidence",level=0.90) 
pred.w.clim

pred.w.plim <- predict(lm(Ht ~ Dbh+Dbhsq), new, interval="prediction",level=0.90)
pred.w.plim

lm.height2<-lm(Ht~Dbhsq)
anova(lm(Ht~Dbhsq)) 
anova(lm.height2,lm.height)                # partial F test to compare the two nested models

#############################################################################################
#  Clean up all of your files, or shut down R before doing another exercise
#############################################################################################
rm(list=ls(all=TRUE))















